==> wiki3_4_0.zip: wiki3_4_0/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# ХݡȤƤ뤿Υեɽޤ
# Ȥƥץ̾ӥХΥƥꤷޤ
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# ΥեफХݡȤƤ
# <pre>
#  BugTrack-ץ̾/ֹ
# </pre>
# Ȥ̾Υڡޤ
# ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
# ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
# 񤭴Ƥ
# 
################################################################################
package plugin::bugtrack::BugTrack;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# 饤ץ饰Υ᥽å
#===============================================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $project = shift;
	my @category = @_;
	
	if($project eq ""){
		return "<font class=\"error\">ץ̾ꤵƤޤ</font>";
	}
	if($#category == -1){
		return "<font class=\"error\">ƥ꤬ꤵƤޤ</font>";
	}
	
	my $buf = "";
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$buf.= "<form action=\"$main::script_name\" method=\"post\">\n".
	       "<table>\n".
	       "<tr><th>Ƽ</th><td><input type=\"text\" name=\"name\"></td></tr>\n".
	       "<tr><th>ޥ</th><td><input type=\"text\" name=\"subject\" size=\"60\"></td></tr>\n";
	
	#------------------------------------------------------------------
	# ƥ
	$buf .= "<tr><th>ƥ</th><td><select name=\"category\">";
	foreach(@category){
		$buf .= "<option value=\"".Util::escapeHTML($_)."\">".Util::escapeHTML($_)."</option>";
	}
	$buf .= "</td></tr>\n";
	#------------------------------------------------------------------
	# ͥ
	$buf .= "<tr><th>ͥ</th><td><select name=\"priority\">";
	foreach(@priority){
		$buf .= "<option value=\"".Util::escapeHTML($_)."\">".Util::escapeHTML($_)."</option>";
	}
	$buf .= "</td></tr>\n";
	#------------------------------------------------------------------
	# 
	$buf .= "<tr><th></th><td><select name=\"status\">";
	foreach(@status){
		$buf .= "<option value=\"".Util::escapeHTML($_)."\">".Util::escapeHTML($_)."</option>";
	}
	$buf .= "</td></tr>\n";
	
	$buf .= "<tr><th></th><td><textarea name=\"content\" rows=\"8\" cols=\"60\"></textarea></td></tr>\n".
	        "</table>\n".
	        "<input type=\"submit\" value=\"   \">\n".
	        "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	        "<input type=\"hidden\" name=\"project\" value=\"".Util::escapeHTML($project)."\">\n".
	        "</form>\n";
	
	return $buf;
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/bugtrack/BugTrack.pm <==
################################################################################
#
# ХݡȤƤ뤿Υեɽޤ
# Ȥƥץ̾ӥХΥƥꤷޤ
# <pre>
# {{bugtrack ץ̾,ƥ꣱,ƥꣲ...}}
# </pre>
# ΥեफХݡȤƤ
# <pre>
#  BugTrack-ץ̾/ֹ
# </pre>
# Ȥ̾Υڡޤ
# ϿѤߤΥХݡȤξ֤ѹϡХݡȤľԽ
# ֤ơססִλס֥꡼ѡסαסֵѲפΤ줫
# 񤭴Ƥ
# 
################################################################################
package plugin::bugtrack::BugTrack;
use strict;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===============================================================================
# 饤ץ饰Υ᥽å
#===============================================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $project = shift;
	my @category = @_;
	
	if($project eq ""){
		return "<font class=\"error\">ץ̾ꤵƤޤ</font>";
	}
	if($#category == -1){
		return "<font class=\"error\">ƥ꤬ꤵƤޤ</font>";
	}
	
	my $template = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/bugtrack.tmpl",
	                                   die_on_bad_params => 0);
	
	my @priority = ("۵","","","");
	my @status   = ("","","λ","꡼","α","Ѳ");
	
	$template->param(PRIORITY => &make_array_ref(@priority));
	$template->param(STATUS   => &make_array_ref(@status));
	$template->param(CATEGORY => &make_array_ref(@category));
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"post\">\n".
	          $template->output().
	          "<input type=\"hidden\" name=\"action\" value=\"BUG_POST\">\n".
	          "<input type=\"hidden\" name=\"project\" value=\"".&Util::escapeHTML($project)."\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ܤե󥹤
#===============================================================================
sub make_array_ref {
	my @array    = @_;
	my $arrayref = [];
	foreach(@array){
		push(@$arrayref,{NAME=>$_,VALUE=>$_});
	}
	return $arrayref;
}


1;
